## $Id: browser.py 8144 2012-04-13 15:10:17Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from zope.formlib.textwidgets import BytesDisplayWidget
from zope.component import getUtility
from waeup.kofa.widgets.datewidget import (
    FriendlyDateWidget, FriendlyDateDisplayWidget
    )
from waeup.kofa.interfaces import IExtFileStore
from waeup.kofa.students.browser import (
    StudentPersonalDisplayFormPage,
    StudentClearanceManageFormPage, StudentClearanceEditFormPage,
    StudentClearanceDisplayFormPage, OnlinePaymentCallbackPage,
    ExportPDFClearanceSlipPage, StudentBaseManageFormPage,
    StudentBaseEditFormPage, StudentPersonalEditFormPage)
from waeup.kofa.students.viewlets import RequestCallbackActionButton
from waeup.uniben.students.interfaces import (
    IStudentBase, IStudent, IStudentPersonal,
    IUGStudentClearance,IPGStudentClearance,
    )
from waeup.uniben.interfaces import MessageFactory as _
from waeup.uniben.widgets.phonewidget import PhoneWidget

class RequestCallbackActionButton(RequestCallbackActionButton):
    """ Do not display the base package callback button in custom pages.
    """
    @property
    def target_url(self):
        return ''

class OnlinePaymentCallbackPage(OnlinePaymentCallbackPage):
    """ Neutralize callback simulation view
    """
    def update(self):
        return

class StudentBaseManageFormPage(StudentBaseManageFormPage):
    """ View to manage student base data
    """
    form_fields = grok.AutoFields(IStudentBase).omit('student_id')
    form_fields['phone'].custom_widget = PhoneWidget

class StudentBaseEditFormPage(StudentBaseEditFormPage):
    """ View to edit student base data
    """
    form_fields = grok.AutoFields(IStudentBase).select(
        'email', 'phone')
    form_fields['phone'].custom_widget = PhoneWidget


class StudentPersonalDisplayFormPage(StudentPersonalDisplayFormPage):
    """ Page to display student personal data
    """
    grok.context(IStudent)
    form_fields = grok.AutoFields(IStudentPersonal)
    form_fields['perm_address'].custom_widget = BytesDisplayWidget


class StudentPersonalEditFormPage(StudentPersonalEditFormPage):
    """ Page to edit personal data
    """
    form_fields = grok.AutoFields(IStudentPersonal)


class StudentClearanceDisplayFormPage(StudentClearanceDisplayFormPage):
    """ Page to display student clearance data
    """
    grok.context(IStudent)

    @property
    def form_fields(self):
        cm = getattr(self.context,'current_mode', None)
        if cm is not None and cm.startswith('pg'):
            form_fields = grok.AutoFields(IPGStudentClearance).omit('clearance_locked')
            form_fields['emp_start'].custom_widget = FriendlyDateDisplayWidget('le')
            form_fields['emp_end'].custom_widget = FriendlyDateDisplayWidget('le')
            form_fields['emp2_start'].custom_widget = FriendlyDateDisplayWidget('le')
            form_fields['emp2_end'].custom_widget = FriendlyDateDisplayWidget('le')
        else:
            form_fields = grok.AutoFields(IUGStudentClearance).omit('clearance_locked')
        form_fields['date_of_birth'].custom_widget = FriendlyDateDisplayWidget('le')
        form_fields['fst_sit_date'].custom_widget = FriendlyDateDisplayWidget('le')
        form_fields['scd_sit_date'].custom_widget = FriendlyDateDisplayWidget('le')
        form_fields['scd_sit_date'].custom_widget = FriendlyDateDisplayWidget('le')
        form_fields['alr_date'].custom_widget = FriendlyDateDisplayWidget('le')
        return form_fields

class ExportPDFClearanceSlipPage(ExportPDFClearanceSlipPage):
    """Deliver a PDF slip of the context.
    """
    grok.context(IStudent)

    @property
    def form_fields(self):
        cm = getattr(self.context,'current_mode', None)
        if cm is not None and cm.startswith('pg'):
            form_fields = grok.AutoFields(IPGStudentClearance).omit('clearance_locked')
            form_fields['emp_start'].custom_widget = FriendlyDateDisplayWidget('le')
            form_fields['emp_end'].custom_widget = FriendlyDateDisplayWidget('le')
            form_fields['emp2_start'].custom_widget = FriendlyDateDisplayWidget('le')
            form_fields['emp2_end'].custom_widget = FriendlyDateDisplayWidget('le')
        else:
            form_fields = grok.AutoFields(IUGStudentClearance).omit('clearance_locked')
        form_fields['date_of_birth'].custom_widget = FriendlyDateDisplayWidget('le')
        form_fields['fst_sit_date'].custom_widget = FriendlyDateDisplayWidget('le')
        form_fields['scd_sit_date'].custom_widget = FriendlyDateDisplayWidget('le')
        form_fields['scd_sit_date'].custom_widget = FriendlyDateDisplayWidget('le')
        form_fields['alr_date'].custom_widget = FriendlyDateDisplayWidget('le')
        return form_fields

class StudentClearanceManageFormPage(StudentClearanceManageFormPage):
    """ Page to edit student clearance data
    """
    grok.context(IStudent)

    @property
    def form_fields(self):
        cm = getattr(self.context,'current_mode', None)
        if cm is not None and cm.startswith('pg'):
            form_fields = grok.AutoFields(IPGStudentClearance)
            form_fields['emp_start'].custom_widget = FriendlyDateWidget('le-year')
            form_fields['emp_end'].custom_widget = FriendlyDateWidget('le-year')
            form_fields['emp2_start'].custom_widget = FriendlyDateWidget('le-year')
            form_fields['emp2_end'].custom_widget = FriendlyDateWidget('le-year')
        else:
            form_fields = grok.AutoFields(IUGStudentClearance)
        form_fields['date_of_birth'].custom_widget = FriendlyDateWidget('le-year')
        form_fields['fst_sit_date'].custom_widget = FriendlyDateWidget('le-year')
        form_fields['scd_sit_date'].custom_widget = FriendlyDateWidget('le-year')
        form_fields['scd_sit_date'].custom_widget = FriendlyDateWidget('le-year')
        form_fields['alr_date'].custom_widget = FriendlyDateWidget('le-year')


        return form_fields

class StudentClearanceEditFormPage(StudentClearanceEditFormPage):
    """ View to edit student clearance data by student
    """
    grok.context(IStudent)

    @property
    def form_fields(self):
        cm = getattr(self.context,'current_mode', None)
        if cm is not None and cm.startswith('pg'):
            form_fields = grok.AutoFields(IPGStudentClearance).omit('clearance_locked')
            form_fields['emp_start'].custom_widget = FriendlyDateWidget('le-year')
            form_fields['emp_end'].custom_widget = FriendlyDateWidget('le-year')
            form_fields['emp2_start'].custom_widget = FriendlyDateWidget('le-year')
            form_fields['emp2_end'].custom_widget = FriendlyDateWidget('le-year')
        else:
            form_fields = grok.AutoFields(IUGStudentClearance).omit('clearance_locked')
        form_fields['date_of_birth'].custom_widget = FriendlyDateWidget('le-year')
        form_fields['fst_sit_date'].custom_widget = FriendlyDateWidget('le-year')
        form_fields['scd_sit_date'].custom_widget = FriendlyDateWidget('le-year')
        form_fields['scd_sit_date'].custom_widget = FriendlyDateWidget('le-year')
        form_fields['alr_date'].custom_widget = FriendlyDateWidget('le-year')
        return form_fields

    def dataNotComplete(self):
        store = getUtility(IExtFileStore)
        if not store.getFileByContext(self.context, attr=u'birth_certicicate.jpg'):
            return _('No birth certificate uploaded.')
        if not store.getFileByContext(self.context, attr=u'ref_let.jpg'):
            return _('No referee letter uploaded.')
        if not store.getFileByContext(self.context, attr=u'acc_let.jpg'):
            return _('No acceptance letter uploaded.')
        if not store.getFileByContext(self.context, attr=u'fst_sit_scan.jpg'):
            return _('No first sitting result uploaded.')
        return False

